==> openshift-model-installer-5.12.3-sources.jar: io/fabric8/openshift/api/model/installer/baremetal/v1/BMCBuilder.java <==
package io.fabric8.openshift.api.model.installer.baremetal.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BMCBuilder extends io.fabric8.openshift.api.model.installer.baremetal.v1.BMCFluentImpl<io.fabric8.openshift.api.model.installer.baremetal.v1.BMCBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.installer.baremetal.v1.BMC,io.fabric8.openshift.api.model.installer.baremetal.v1.BMCBuilder>{
  public BMCBuilder() {
    this(false);
  }
  public BMCBuilder(java.lang.Boolean validationEnabled) {
    this(new BMC(), validationEnabled);
  }
  public BMCBuilder(io.fabric8.openshift.api.model.installer.baremetal.v1.BMCFluent<?> fluent) {
    this(fluent, false);
  }
  public BMCBuilder(io.fabric8.openshift.api.model.installer.baremetal.v1.BMCFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BMC(), validationEnabled);
  }
  public BMCBuilder(io.fabric8.openshift.api.model.installer.baremetal.v1.BMCFluent<?> fluent,io.fabric8.openshift.api.model.installer.baremetal.v1.BMC instance) {
    this(fluent, instance, false);
  }
  public BMCBuilder(io.fabric8.openshift.api.model.installer.baremetal.v1.BMCFluent<?> fluent,io.fabric8.openshift.api.model.installer.baremetal.v1.BMC instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddress(instance.getAddress()); 
    fluent.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    fluent.withPassword(instance.getPassword()); 
    fluent.withUsername(instance.getUsername()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BMCBuilder(io.fabric8.openshift.api.model.installer.baremetal.v1.BMC instance) {
    this(instance,false);
  }
  public BMCBuilder(io.fabric8.openshift.api.model.installer.baremetal.v1.BMC instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddress(instance.getAddress()); 
    this.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    this.withPassword(instance.getPassword()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.installer.baremetal.v1.BMCFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.installer.baremetal.v1.BMC build() {
    BMC buildable = new BMC(fluent.getAddress(),fluent.getDisableCertificateVerification(),fluent.getPassword(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BMCBuilder that = (BMCBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-installer-6.5.1-sources.jar: io/fabric8/openshift/api/model/installer/baremetal/v1/BMCBuilder.java <==
package io.fabric8.openshift.api.model.installer.baremetal.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BMCBuilder extends BMCFluentImpl<BMCBuilder> implements VisitableBuilder<BMC,BMCBuilder>{
  public BMCBuilder() {
    this(false);
  }
  public BMCBuilder(Boolean validationEnabled) {
    this(new BMC(), validationEnabled);
  }
  public BMCBuilder(BMCFluent<?> fluent) {
    this(fluent, false);
  }
  public BMCBuilder(BMCFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BMC(), validationEnabled);
  }
  public BMCBuilder(BMCFluent<?> fluent,BMC instance) {
    this(fluent, instance, false);
  }
  public BMCBuilder(BMCFluent<?> fluent,BMC instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddress(instance.getAddress()); 
    fluent.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    fluent.withPassword(instance.getPassword()); 
    fluent.withUsername(instance.getUsername()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BMCBuilder(BMC instance) {
    this(instance,false);
  }
  public BMCBuilder(BMC instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddress(instance.getAddress()); 
    this.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    this.withPassword(instance.getPassword()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  BMCFluent<?> fluent;
  Boolean validationEnabled;
  public BMC build() {
    BMC buildable = new BMC(fluent.getAddress(),fluent.getDisableCertificateVerification(),fluent.getPassword(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
